# 1.  Gb.df is based on 16 sessions of 224 trials each.  Estimate sensitivity and bias
    # for each session individually and plot them as a function of session.  Are there
    # any learning trends?  How variable are the measures?
load("GabResp.Rdata")  # load data file
Gb.df <- data.frame( Resp = GabResp %in% c("H", "FA"),	
                  Stim = GabResp %in% c("H", "M"))
Gb.glm <- glm(Resp ~ Stim, binomial(probit), Gb.df)
x <- seq(0L, 15L) * 224 + 1
res.ses <- t(sapply(x, function(ix){
	coef(update(Gb.glm, data = Gb.df[seq(ix, ix + 223), ]))
}))
par(mfrow = c(2, 1))
plot(1:16, res.ses[, 1], ylim = c(-1, 1), 
	xlab = "Session", ylab = expression(beta[0]))
abline(h = mean(res.ses[, 1]))
abline(h = coef(Gb.glm)[1], col = "blue", lty = 2)	
plot(1:16, res.ses[, 2], ylim = c(0.5, 1.5),
	xlab = "Session", ylab = expression(beta[1]))
abline(h = coef(Gb.glm)[2], col = "blue", lty = 2)	
abline(h = mean(res.ses[, 2]))
ses <- 1:16
summary(lm(res.ses ~ ses))

cbind(Mean = apply(res.ses, 2, mean),
		SD = apply(res.ses, 2, sd))
		
cor(res.ses)  
dev.new()
plot(res.ses, xlab = expression(beta[0]), ylab = expression(beta[1]))
abline(lm(res.ses[, 2] ~ res.ses[, 1]))


# 2.  Fit the SDT detection model to the Gb.df data set cumulatively by session, 
    # i.e., first the first session, then the first and second sessions, etc. 
    # How do the SE’s of the parameter estimates vary with the number of trials?
SE.cum <- t(sapply(x, function(ix){
	res <- update(Gb.glm, data = Gb.df[seq(1, ix + 223), ])
	coef(summary(res))[, 2]
})) 
matplot(SE.cum, type = "b")
dev.new()
matplot(SE.cum, log = "xy")
(SE.cum.lm <- lm(log10(SE.cum) ~ log10(ses)))
cc <- coef(SE.cum.lm)
lines(ses, 10^cc[1, 1] * ses^cc[2, 1])
lines(ses, 10^cc[1, 2] * ses^cc[2, 2])
lines(ses, 10^cc[1, 1] * ses^-0.5, col = "blue", lty = 2)
lines(ses, 10^cc[1, 2] * ses^-0.5, col = "blue", lty = 2)

# 3.  Bootstrap standard errors.  With the model object, Gb.glm, obtain the fitted values 
    # with the fitted method (fitted(Gb.glm)).  Then, use these as probabilities 
    # with the rbinom function to generate new Bernoulli responses based on the 
    # fitted probabilities.  Use these new simulated responses in place of the actual ones 
    # to fit a glm, estimating new parameters, β₀* and β₁*, and store them.  Repeat
    # this many time (e.g., 10000).  Calculate the mean and SD’s of the bootstrap
    # parameter estimates.  The difference between the mean and value obtained
    # on the original data is an estimate of bias.  The SD’s are estimates of the SE’s,
    # the 0.025 and 0.975 quantiles of the distribution are 95% confidence interval
    # estimates.
library(parallel)  # should run faster if multiple cores present and run in parallel
cl <- makeCluster(getOption("cl.cores", detectCores()))
N <- 10000
Gb.fit <- fitted(Gb.glm)    
Resp.bs <- rbinom(N * length(Gb.fit), 1, Gb.fit)
Resp.bs <- matrix(Resp.bs, nrow = length(Gb.fit), ncol = N)
clusterExport(cl, c("Resp.bs", "Gb.df"))
Gb.bs <- t(parSapply(cl, seq(N), function(ix){ # this step will take some time
	Gb.bt <- glm(Resp.bs[, ix] ~ Gb.df$Stim, binomial(probit))
	coef(Gb.bt)
}))
par(mfrow = c(2, 1))
hist(Gb.bs[, 1], xlab = expression(beta[0]))
hist(Gb.bs[, 2], xlab = expression(beta[1]))
Bs.mn <- apply(Gb.bs, 2, mean)
bias <- coef(Gb.glm) -  Bs.mn
Bs.se <- apply(Gb.bs, 2, sd)
( Gb.bsCI <- t(apply(Gb.bs, 2, quantile, p = c(0.025, 0.975))) )
#  compare w/ GLM method from vcov matrix
( Gb.CI <- confint(Gb.glm) )


    